@@ -1,5 +1,5 @@
 package Dist::Zilla::Plugin::ChangelogFromGit::CPAN::Changes;
-$Dist::Zilla::Plugin::ChangelogFromGit::CPAN::Changes::VERSION = '0.0.13';
+$Dist::Zilla::Plugin::ChangelogFromGit::CPAN::Changes::VERSION = '0.0.14';
 # ABSTRACT: Generate valid CPAN::Changes Changelogs from git
 
 use v5.10.1;
@@ -9,6 +9,7 @@ use Class::Load 'try_load_class';
 use CPAN::Changes::Release;
 use CPAN::Changes;
 use DateTime;
+use Encode;
 use Git::Wrapper;
 
 with qw/
@@ -71,7 +72,9 @@ has _git_can_mailmap => (
     lazy    => 1,
     isa     => 'Bool',
     default => sub {
-        return version->parse($_[0]->_git->version) < '1.8.2' ? 0 : 1;
+        my ($gv) = $_[0]->git->version =~ /(\d+\.\d+\.\d+)/;
+        $gv //= 0;
+        return version->parse($gv) < '1.8.2' ? 0 : 1;
     },
 );
 
@@ -331,6 +334,10 @@ sub _get_changes {
             next if $commit->{subject} =~ /^Release /;
             next if $commit->{subject} =~ /^Merge (pull|branch)/;
 
+            unless (utf8::is_utf8($commit->{subject})) {
+                $commit->{subject} = Encode::decode_utf8($commit->{subject});
+            }
+
             if ($self->show_author && exists $commit->{author}) {
                 my $author = $commit->{author};
 
@@ -338,6 +345,10 @@ sub _get_changes {
                     $author .= ' ' . $commit->{email};
                 }
 
+                unless (utf8::is_utf8($author)) {
+                    $author = Encode::decode_utf8($author);
+                }
+
                 if ($self->group_by_author) {
                     my $group = $author;
                     $release->add_changes({group => $group},
@@ -374,7 +385,7 @@ Dist::Zilla::Plugin::ChangelogFromGit::CPAN::Changes - Generate valid CPAN::Chan
 
 =head1 VERSION
 
-version 0.0.13
+version 0.0.14
 
 =head1 SYNOPSIS
 
